unittest

Module unittest |
[hide private]
[frames] | no frames]

# Module unittest

source code

    Python unit testing framework, based on Erich Gamma's JUnit and Kent Beck's
    Smalltalk testing framework.

    This module contains the core framework classes that form the basis of
    specific test cases and suites (TestCase, TestSuite etc.), and also a
    text-based utility class for running the tests and reporting the results
     (TextTestRunner).

    Simple usage:

        import unittest

        class IntegerArithmenticTestCase(unittest.TestCase):
            def testAdd(self):  ## test method names begin 'test*'
                self.assertEquals((1 + 2), 3)
                self.assertEquals(0 + 1, 1)
            def testMultiply(self):
                self.assertEquals((0 * 10), 0)
                self.assertEquals((5 * 8), 40)

        if __name__ == '__main__':
            unittest.main()

    Further information is available in the bundled documentation, and from

      http://pyunit.sourceforge.net/

    Copyright (c) 1999-2003 Steve Purcell
    This module is free software, and you may redistribute it and/or modify
    it under the same terms as Python itself, so long as this copyright message
    and disclaimer are retained in their original form.

    IN NO EVENT SHALL THE AUTHOR BE LIABLE TO ANY PARTY FOR DIRECT, INDIRECT,
    SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OF
    THIS CODE, EVEN IF THE AUTHOR HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH
    DAMAGE.

    THE AUTHOR SPECIFICALLY DISCLAIMS ANY WARRANTIES, INCLUDING, BUT NOT
    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
    PARTICULAR PURPOSE.  THE CODE PROVIDED HEREUNDER IS ON AN "AS IS" BASIS,
    AND THERE IS NO OBLIGATION WHATSOEVER TO PROVIDE MAINTENANCE,
    SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS.

Version: 1.63

Author: Steve Purcell

Classes | [hide private]
| FunctionTestCase A test case that wraps a test function.
| TestCase A class whose instances are single test cases.
| TestLoader This class is responsible for loading tests according to various criteria and returning them wrapped in a Test
| TestProgram A command-line program that runs a set of tests; this is primarily for making test modules conveniently executable.
| TestResult Holder for test result information.
| TestSuite A test suite is a composite test consisting of a number of TestCases.
| TextTestRunner A test runner class that displays results in textual form.
| _TextTestResult A test result class that can print formatted text results to a stream.
| _WritelnDecorator Used to decorate file-like objects with a handy 'writeln' method
| main A command-line program that runs a set of tests; this is primarily for making test modules conveniently executable.

Functions | [hide private]
_makeLoader(prefix, sortUsing, suiteClass=None) | source code
_strclass(cls) | source code
findTestCases(module, prefix=`'``test``'`, sortUsing=<built-in function cmp>, suiteClass=<class 'unittest.TestSuite'>) | source code
getTestCaseNames(testCaseClass, prefix, sortUsing=<built-in function cmp>) | source code
makeSuite(testCaseClass, prefix=`'``test``'`, sortUsing=<built-in function cmp>, suiteClass=<class 'unittest.TestSuite'>) | source code

Variables | [hide private]
| __email__ = ``'``stephen_purcell at yahoo dot com``'``
| __unittest = `1`
| defaultTestLoader = `<unittest.TestLoader object at 0xf98590>`